@@ -20,6 +20,8 @@
 #include "src/util.h"
 #include "src/priv.h"
 #include "classes/http.h"
+#include "zend_exceptions.h"
+#include "ext/spl/spl_exceptions.h"
 
 zend_class_entry *php_event_ce;
 zend_class_entry *php_event_base_ce;
@@ -38,6 +40,8 @@ zend_class_entry *php_event_http_req_ce;
 zend_class_entry *php_event_ssl_context_ce;
 #endif
 
+zend_class_entry *php_event_exception_ce;
+
 static HashTable classes;
 
 static HashTable event_properties;
@@ -98,6 +102,21 @@ ZEND_GET_MODULE(event)
 #endif
 
 
+zend_class_entry *php_event_get_exception_base(int root) /* {{{ */
+{
+	if (!root) {
+		return spl_ce_RuntimeException;
+	}
+	return zend_ce_exception;
+}
+/* }}} */
+
+zend_class_entry *php_event_get_exception(void)/*{{{*/
+{
+	return php_event_exception_ce;
+}/*}}}*/
+
+
 /* {{{ Private functions */
 
 static void free_prop_handler(zval *el)/*{{{*/
@@ -566,13 +585,6 @@ static zend_object * event_buffer_object_create(zend_class_entry *ce)/*{{{*/
 	return &intern->zo;
 }/*}}}*/
 
-static zend_object * event_util_object_create(zend_class_entry *ce)/*{{{*/
-{
-	/* EventUtil is a singleton. This function should never be called */
-	PHP_EVENT_ASSERT(0);
-	return NULL;
-}/*}}}*/
-
 #ifdef HAVE_EVENT_OPENSSL_LIB
 static zend_object * event_ssl_context_object_create(zend_class_entry *ce)/*{{{*/
 {
@@ -965,9 +977,11 @@ static void php_event_add_property(HashTable *h, const char *name, size_t name_l
 	zend_string_release(p.name);
 }/*}}}*/
 
+
 static zend_always_inline void register_classes()/*{{{*/
 {
 	zend_class_entry *ce;
+	zend_class_entry ce_exception;
 
 	PHP_EVENT_REGISTER_CLASS("Event", event_object_create, php_event_ce, php_event_ce_functions);
 	ce = php_event_ce;
@@ -1044,7 +1058,7 @@ static zend_always_inline void register_classes()/*{{{*/
 	ce->ce_flags |= ZEND_ACC_FINAL;
 #endif /* HAVE_EVENT_EXTRA_LIB */
 
-	PHP_EVENT_REGISTER_CLASS("EventUtil", event_util_object_create, php_event_util_ce,
+	PHP_EVENT_REGISTER_CLASS("EventUtil", zend_objects_new, php_event_util_ce,
 			php_event_util_ce_functions);
 	ce = php_event_util_ce;
 	ce->ce_flags |= ZEND_ACC_FINAL;
@@ -1061,6 +1075,15 @@ static zend_always_inline void register_classes()/*{{{*/
 	PHP_EVENT_DECL_PROP_NULL(ce, local_pk,   ZEND_ACC_PUBLIC);
 	zend_hash_add_ptr(&classes, ce->name, &event_ssl_context_properties);
 #endif /* HAVE_EVENT_OPENSSL_LIB */
+
+#ifdef PHP_EVENT_NS
+	INIT_NS_CLASS_ENTRY(ce_exception, PHP_EVENT_NS, "EventException", NULL);
+#else
+	INIT_CLASS_ENTRY(ce_exception, "EventException", NULL);
+#endif
+
+	php_event_exception_ce = zend_register_internal_class_ex(&ce_exception, php_event_get_exception_base(0));
+	zend_declare_property_null(php_event_exception_ce, "errorInfo", sizeof("errorInfo") - 1, ZEND_ACC_PUBLIC);
 }/*}}}*/
 
 /* Private functions }}} */
@@ -1104,6 +1127,12 @@ PHP_MINIT_FUNCTION(event)
 	PHP_EVENT_INIT_X_OBJ_HANDLERS(ssl_context);
 #endif
 
+#ifdef PHP_EVENT_NS
+	REGISTER_STRING_CONSTANT("EVENT_NS", PHP_EVENT_NS, CONST_CS | CONST_PERSISTENT);
+#else
+	REGISTER_STRING_CONSTANT("EVENT_NS", "", CONST_CS | CONST_PERSISTENT);
+#endif
+
 	zend_hash_init(&classes, 4, NULL, NULL, 1);
 	register_classes();
 
@@ -1334,6 +1363,7 @@ PHP_MINIT_FUNCTION(event)
 	event_set_fatal_callback(fatal_error_cb);
 	event_set_log_callback(log_cb);
 
+
 	return SUCCESS;
 }
 /* }}} */
